yt.visualization.volume_rendering.camera.PerspectiveCamera.rotation — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.camera.PerspectiveCamera.rotation

`PerspectiveCamera.` `rotation`(theta, n_steps, rot_vector=None, clip_ratio=None)

  Loop over rotate, creating a rotation

  This will yield n_steps snapshots until the current view has been rotated by an angle theta

  Parameters: | theta : float, in radians Angle (in radians) by which to rotate the view. n_steps : int The number of look_at snapshots to make. rot_vector : array_like, optional Specify the rotation vector around which rotation will occur. Defaults to None, which sets rotation around the original north_vector clip_ratio : float, optional If supplied, the ‘max_val’ argument to write_bitmap will be handed clip_ratio * image.std()

  Examples

      >>> for i, snapshot in enumerate(cam.rotation(np.pi, 10)):
      ...     iw.write_bitmap(snapshot, 'rotation_%04i.png' % i)